rpms/gtk2/F-10 missing-compose-seqs.patch, NONE, 1.1 gtk2.spec, 1.336, 1.337

Matthias Clasen mclasen at fedoraproject.org
Fri Nov 28 00:11:15 UTC 2008


Author: mclasen

Update of /cvs/extras/rpms/gtk2/F-10
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv29942

Modified Files:
	gtk2.spec 
Added Files:
	missing-compose-seqs.patch 
Log Message:
add missing compose sequences


missing-compose-seqs.patch:

--- NEW FILE missing-compose-seqs.patch ---
diff -up gtk+-2.14.5/gtk/gtkimcontextsimpleseqs.h.compose-seqs gtk+-2.14.5/gtk/gtkimcontextsimpleseqs.h
--- gtk+-2.14.5/gtk/gtkimcontextsimpleseqs.h.compose-seqs	2008-11-27 19:07:16.000000000 -0500
+++ gtk+-2.14.5/gtk/gtkimcontextsimpleseqs.h	2008-11-27 19:07:29.000000000 -0500
@@ -18,9 +18,10 @@
  */
 
 /*
- * File auto-generated from script found at http://bugzilla.gnome.org/show_bug.cgi?id=321896
+ * File auto-generated from script found at gtk/compose-parse.py, with the --gtk parameter,
  * using the input files
  *  Input   : http://gitweb.freedesktop.org/?p=xorg/lib/libX11.git;a=blob_plain;f=nls/en_US.UTF-8/Compose.pre
+ *  Input   : http://svn.gnome.org/viewcvs/gtk%2B/trunk/gtk/gtk-compose-lookaside.txt
  *  Input   : http://www.cl.cam.ac.uk/~mgk25/ucs/keysyms.txt
  *  Input   : http://www.unicode.org/Public/UNIDATA/UnicodeData.txt
  *
@@ -67,48 +68,81 @@
  */
 
 static const guint16 gtk_compose_seqs_compact[] = {
-GDK_dead_stroke, 132, 166, 172, 172, 172, 
-GDK_dead_grave, 172, 228, 315, 527, 527, 
-GDK_dead_acute, 527, 585, 678, 954, 954, 
-GDK_dead_circumflex, 954, 1042, 1042, 1242, 1242, 
-GDK_dead_tilde, 1242, 1302, 1365, 1505, 1505, 
-GDK_dead_macron, 1505, 1529, 1529, 1601, 1601, 
-GDK_dead_breve, 1601, 1637, 1637, 1661, 1661, 
-GDK_dead_abovedot, 1661, 1675, 1675, 1707, 1707, 
-GDK_dead_diaeresis, 1707, 1771, 1771, 1795, 1795, 
-GDK_dead_abovering, 1795, 1799, 1799, 1799, 1799, 
-GDK_dead_doubleacute, 1799, 1807, 1807, 1807, 1807, 
-GDK_dead_caron, 1807, 1811, 1811, 1819, 1819, 
-GDK_dead_cedilla, 1819, 1823, 1823, 1823, 1823, 
-GDK_dead_ogonek, 1823, 1827, 1827, 1827, 1827, 
-GDK_dead_iota, 1827, 1849, 1948, 2380, 3040, 
-GDK_dead_voiced_sound, 3040, 3086, 3086, 3086, 3086, 
-GDK_dead_semivoiced_sound, 3086, 3096, 3096, 3096, 3096, 
-GDK_dead_belowdot, 3096, 3106, 3106, 3122, 3122, 
-GDK_dead_hook, 3122, 3126, 3126, 3182, 3182, 
-GDK_dead_psili, 3182, 3210, 3210, 3210, 3210, 
-GDK_dead_dasia, 3210, 3242, 3242, 3242, 3242, 
-GDK_Multi_key, 3242, 3242, 8078, 11766, 13626, 
+GDK_dead_stroke, 138, 226, 235, 235, 235, 
+GDK_Greek_accentdieresis, 235, 239, 239, 239, 239, 
+GDK_dead_grave, 239, 299, 386, 598, 598, 
+GDK_dead_acute, 598, 664, 760, 1036, 1036, 
+GDK_dead_circumflex, 1036, 1176, 1176, 1376, 1376, 
+GDK_dead_tilde, 1376, 1458, 1521, 1661, 1661, 
+GDK_dead_macron, 1661, 1707, 1707, 1779, 1779, 
+GDK_dead_breve, 1779, 1833, 1833, 1857, 1857, 
+GDK_dead_abovedot, 1857, 1887, 1890, 1922, 1922, 
+GDK_dead_diaeresis, 1922, 2010, 2019, 2043, 2043, 
+GDK_dead_abovering, 2043, 2053, 2053, 2053, 2053, 
+GDK_dead_doubleacute, 2053, 2063, 2063, 2063, 2063, 
+GDK_dead_caron, 2063, 2089, 2089, 2097, 2097, 
+GDK_dead_cedilla, 2097, 2111, 2111, 2111, 2111, 
+GDK_dead_ogonek, 2111, 2121, 2121, 2121, 2121, 
+GDK_dead_iota, 2121, 2143, 2242, 2674, 3334, 
+GDK_dead_voiced_sound, 3334, 3380, 3380, 3380, 3380, 
+GDK_dead_semivoiced_sound, 3380, 3390, 3390, 3390, 3390, 
+GDK_dead_belowdot, 3390, 3400, 3400, 3416, 3416, 
+GDK_dead_hook, 3416, 3494, 3494, 3550, 3550, 
+GDK_dead_psili, 3550, 3578, 3578, 3578, 3578, 
+GDK_dead_dasia, 3578, 3610, 3610, 3610, 3610, 
+GDK_Multi_key, 3610, 3610, 9589, 13297, 15157, 
+GDK_space, 0x002F, 
+GDK_2, 0x01BB, 
+GDK_A, 0x023A, 
+GDK_B, 0x0243, 
+GDK_C, 0x023B, 
 GDK_D, 0x0110, 
+GDK_E, 0x0246, 
 GDK_G, 0x01E4, 
 GDK_H, 0x0126, 
 GDK_I, 0x0197, 
+GDK_J, 0x0248, 
 GDK_L, 0x0141, 
 GDK_O, 0x00D8, 
+GDK_P, 0x2C63, 
+GDK_R, 0x024C, 
 GDK_T, 0x0166, 
+GDK_U, 0x0244, 
+GDK_Y, 0x024E, 
 GDK_Z, 0x01B5, 
+GDK_a, 0x2C65, 
 GDK_b, 0x0180, 
+GDK_c, 0x023C, 
 GDK_d, 0x0111, 
+GDK_e, 0x0247, 
 GDK_g, 0x01E5, 
 GDK_h, 0x0127, 
 GDK_i, 0x0268, 
+GDK_j, 0x0249, 
 GDK_l, 0x0142, 
 GDK_o, 0x00F8, 
+GDK_p, 0x1D7D, 
+GDK_r, 0x024D, 
 GDK_t, 0x0167, 
+GDK_u, 0x0289, 
+GDK_y, 0x024F, 
 GDK_z, 0x01B6, 
+GDK_nobreakspace, 0x0338, 
+GDK_Oacute, 0x01FE, 
+GDK_oacute, 0x01FF, 
+0x0237, 0x025F, 
+0x0269, 0x1D7C, 
+GDK_dead_stroke, 0x002F, 
+GDK_lessthanequal, 0x2270, 
+GDK_greaterthanequal, 0x2271, 
 GDK_dead_acute, GDK_O, 0x01FE, 
 GDK_dead_acute, GDK_o, 0x01FF, 
+GDK_dead_abovedot, GDK_j, 0x025F, 
+GDK_Greek_iota, 0x0390, 
+GDK_Greek_upsilon, 0x03B0, 
 GDK_space, 0x0060, 
+GDK_V, 0x01DB, 
+GDK_v, 0x01DC, 
 GDK_Abreve, 0x1EB0, 
 GDK_abreve, 0x1EB1, 
 GDK_Emacron, 0x1E14, 
@@ -219,6 +253,8 @@ GDK_Multi_key, GDK_macron, GDK_O, 0x1E50
 GDK_Multi_key, GDK_macron, GDK_e, 0x1E15, 
 GDK_Multi_key, GDK_macron, GDK_o, 0x1E51, 
 GDK_space, 0x0027, 
+GDK_V, 0x01D7, 
+GDK_v, 0x01D8, 
 GDK_Abreve, 0x1EAE, 
 GDK_abreve, 0x1EAF, 
 GDK_Emacron, 0x1E16, 
@@ -246,9 +282,12 @@ GDK_Greek_iota, 0x03AF, 
 GDK_Greek_omicron, 0x03CC, 
 GDK_Greek_upsilon, 0x03CD, 
 GDK_Greek_omega, 0x03CE, 
+GDK_Sabovedot, 0x1E64, 
+GDK_sabovedot, 0x1E65, 
 GDK_dead_acute, 0x00B4, 
 GDK_dead_stroke, GDK_O, 0x01FE, 
 GDK_dead_stroke, GDK_o, 0x01FF, 
+GDK_dead_diaeresis, GDK_space, 0x0385, 
 GDK_dead_diaeresis, GDK_Greek_iota, 0x0390, 
 GDK_dead_diaeresis, GDK_Greek_upsilon, 0x03B0, 
 GDK_dead_psili, GDK_Greek_ALPHA, 0x1F0C, 
@@ -351,6 +390,7 @@ GDK_space, 0x005E, 
 GDK_parenleft, 0x207D, 
 GDK_parenright, 0x207E, 
 GDK_plus, 0x207A, 
+GDK_minus, 0x207B, 
 GDK_0, 0x2070, 
 GDK_1, 0x00B9, 
 GDK_2, 0x00B2, 
@@ -362,6 +402,31 @@ GDK_7, 0x2077, 
 GDK_8, 0x2078, 
 GDK_9, 0x2079, 
 GDK_equal, 0x207C, 
+GDK_nobreakspace, 0x0302, 
+GDK_Agrave, 0x1EA6, 
+GDK_Aacute, 0x1EA4, 
+GDK_Atilde, 0x1EAA, 
+GDK_Egrave, 0x1EC0, 
+GDK_Eacute, 0x1EBE, 
+GDK_Ograve, 0x1ED2, 
+GDK_Oacute, 0x1ED0, 
+GDK_Otilde, 0x1ED6, 
+GDK_agrave, 0x1EA7, 
+GDK_aacute, 0x1EA5, 
+GDK_atilde, 0x1EAB, 
+GDK_egrave, 0x1EC1, 
+GDK_eacute, 0x1EBF, 
+GDK_ograve, 0x1ED3, 
+GDK_oacute, 0x1ED1, 
+GDK_otilde, 0x1ED7, 
+GDK_Ahook, 0x1EA8, 
+GDK_ahook, 0x1EA9, 
+GDK_Ehook, 0x1EC2, 
+GDK_ehook, 0x1EC3, 
+GDK_Etilde, 0x1EC4, 
+GDK_etilde, 0x1EC5, 
+GDK_Ohook, 0x1ED4, 
+GDK_ohook, 0x1ED5, 
 0x2212, 0x207B, 
 0x4E00, 0x3192, 
 0x4E01, 0x319C, 
@@ -442,8 +507,19 @@ GDK_Multi_key, GDK_underbar, 0x027B, 0x0
 GDK_Multi_key, GDK_underbar, 0x0281, 0x02B6, 
 GDK_Multi_key, GDK_underbar, 0x0295, 0x02E4, 
 GDK_space, 0x007E, 
+GDK_less, 0x2272, 
+GDK_equal, 0x2243, 
+GDK_greater, 0x2273, 
+GDK_Oacute, 0x1E4C, 
+GDK_Odiaeresis, 0x1E4E, 
+GDK_Uacute, 0x1E78, 
+GDK_oacute, 0x1E4D, 
+GDK_odiaeresis, 0x1E4F, 
+GDK_uacute, 0x1E79, 
 GDK_Abreve, 0x1EB4, 
 GDK_abreve, 0x1EB5, 
+GDK_Omacron, 0x022C, 
+GDK_omacron, 0x022D, 
 GDK_Greek_iotadieresis, 0x1FD7, 
 GDK_Greek_upsilondieresis, 0x1FE7, 
 GDK_Greek_alpha, 0x1FB6, 
@@ -528,6 +604,17 @@ GDK_Multi_key, GDK_asciicircum, GDK_o, 0
 GDK_Multi_key, GDK_b, GDK_A, 0x1EB4, 
 GDK_Multi_key, GDK_b, GDK_a, 0x1EB5, 
 GDK_space, 0x00AF, 
+GDK_V, 0x01D5, 
+GDK_v, 0x01D6, 
+GDK_nobreakspace, 0x0304, 
+GDK_Egrave, 0x1E14, 
+GDK_Eacute, 0x1E16, 
+GDK_Ograve, 0x1E50, 
+GDK_Oacute, 0x1E52, 
+GDK_egrave, 0x1E15, 
+GDK_eacute, 0x1E17, 
+GDK_ograve, 0x1E51, 
+GDK_oacute, 0x1E53, 
 GDK_Cyrillic_i, 0x04E3, 
 GDK_Cyrillic_u, 0x04EF, 
 GDK_Cyrillic_I, 0x04E2, 
@@ -558,6 +645,13 @@ GDK_Multi_key, GDK_semicolon, GDK_o, 0x0
 GDK_Multi_key, GDK_asciitilde, GDK_O, 0x022C, 
 GDK_Multi_key, GDK_asciitilde, GDK_o, 0x022D, 
 GDK_space, 0x02D8, 
+GDK_nobreakspace, 0x0306, 
+GDK_Agrave, 0x1EB0, 
+GDK_Aacute, 0x1EAE, 
+GDK_Atilde, 0x1EB4, 
+GDK_agrave, 0x1EB1, 
+GDK_aacute, 0x1EAF, 
+GDK_atilde, 0x1EB5, 
 GDK_Cyrillic_a, 0x04D1, 
 GDK_Cyrillic_ie, 0x04D7, 
 GDK_Cyrillic_i, 0x0439, 
@@ -574,6 +668,8 @@ GDK_Greek_UPSILON, 0x1FE8, 
 GDK_Greek_alpha, 0x1FB0, 
 GDK_Greek_iota, 0x1FD0, 
 GDK_Greek_upsilon, 0x1FE0, 
+GDK_Ahook, 0x1EB2, 
+GDK_ahook, 0x1EB3, 
 GDK_dead_breve, 0x02D8, 
 GDK_Multi_key, GDK_exclam, GDK_A, 0x1EB6, 
 GDK_Multi_key, GDK_exclam, GDK_a, 0x1EB7, 
@@ -582,12 +678,21 @@ GDK_Multi_key, GDK_comma, GDK_e, 0x1E1D,
 GDK_Multi_key, GDK_cedilla, GDK_E, 0x1E1C, 
 GDK_Multi_key, GDK_cedilla, GDK_e, 0x1E1D, 
 GDK_space, 0x02D9, 
+GDK_L, 0x013F, 
 GDK_i, 0x0131, 
+GDK_j, 0x0237, 
+GDK_l, 0x0140, 
+GDK_nobreakspace, 0x0307, 
 GDK_Sacute, 0x1E64, 
 GDK_Scaron, 0x1E66, 
 GDK_sacute, 0x1E65, 
 GDK_scaron, 0x1E67, 
+GDK_Amacron, 0x01E0, 
+GDK_Omacron, 0x0230, 
+GDK_amacron, 0x01E1, 
+GDK_omacron, 0x0231, 
 GDK_dead_abovedot, 0x02D9, 
+GDK_dead_stroke, GDK_j, 0x025F, 
 GDK_Multi_key, GDK_exclam, GDK_S, 0x1E68, 
 GDK_Multi_key, GDK_exclam, GDK_s, 0x1E69, 
 GDK_Multi_key, GDK_apostrophe, GDK_S, 0x1E64, 
@@ -598,8 +703,20 @@ GDK_Multi_key, GDK_acute, GDK_S, 0x1E64,
 GDK_Multi_key, GDK_acute, GDK_s, 0x1E65, 
 GDK_space, 0x0022, 
 GDK_apostrophe, 0x0344, 
+GDK_nobreakspace, 0x0308, 
 GDK_acute, 0x0344, 
+GDK_Iacute, 0x1E2E, 
+GDK_Ugrave, 0x01DB, 
+GDK_Uacute, 0x01D7, 
+GDK_iacute, 0x1E2F, 
+GDK_ugrave, 0x01DC, 
+GDK_uacute, 0x01D8, 
+0x01D3, 0x01D9, 
+0x01D4, 0x01DA, 
+GDK_Amacron, 0x01DE, 
 GDK_Umacron, 0x1E7A, 
+GDK_amacron, 0x01DF, 
+GDK_omacron, 0x022B, 
 GDK_umacron, 0x1E7B, 
 GDK_Ukrainian_i, 0x0457, 
 GDK_Ukrainian_I, 0x0407, 
@@ -628,6 +745,9 @@ GDK_Greek_UPSILON, 0x03AB, 
 GDK_Greek_iota, 0x03CA, 
 GDK_Greek_upsilon, 0x03CB, 
 GDK_dead_diaeresis, 0x00A8, 
+GDK_dead_acute, GDK_space, 0x0385, 
+GDK_dead_acute, GDK_Greek_iota, 0x0390, 
+GDK_dead_acute, GDK_Greek_upsilon, 0x03B0, 
 GDK_Multi_key, GDK_underscore, GDK_U, 0x1E7A, 
 GDK_Multi_key, GDK_underscore, GDK_u, 0x1E7B, 
 GDK_Multi_key, GDK_asciitilde, GDK_O, 0x1E4E, 
@@ -635,18 +755,41 @@ GDK_Multi_key, GDK_asciitilde, GDK_o, 0x
 GDK_Multi_key, GDK_macron, GDK_U, 0x1E7A, 
 GDK_Multi_key, GDK_macron, GDK_u, 0x1E7B, 
 GDK_space, 0x00B0, 
+GDK_nobreakspace, 0x030A, 
+GDK_Aacute, 0x01FA, 
+GDK_aacute, 0x01FB, 
 GDK_dead_abovering, 0x00B0, 
 GDK_space, 0x02DD, 
+GDK_nobreakspace, 0x030B, 
 GDK_Cyrillic_u, 0x04F3, 
 GDK_Cyrillic_U, 0x04F2, 
 GDK_dead_doubleacute, 0x02DD, 
 GDK_space, 0x02C7, 
+GDK_parenleft, 0x208D, 
+GDK_parenright, 0x208E, 
+GDK_plus, 0x208A, 
+GDK_minus, 0x208B, 
+GDK_equal, 0x208C, 
+GDK_V, 0x01D9, 
+GDK_v, 0x01DA, 
+GDK_nobreakspace, 0x030C, 
+0x01F2, 0x01C5, 
+GDK_Sabovedot, 0x1E66, 
+GDK_sabovedot, 0x1E67, 
 GDK_dead_caron, 0x02C7, 
 GDK_Multi_key, GDK_quotedbl, GDK_U, 0x01D9, 
 GDK_Multi_key, GDK_quotedbl, GDK_u, 0x01DA, 
 GDK_space, 0x00B8, 
+GDK_nobreakspace, 0x0327, 
+GDK_cent, 0x20B5, 
+GDK_Cacute, 0x1E08, 
+GDK_cacute, 0x1E09, 
+GDK_ColonSign, 0x20B5, 
 GDK_dead_cedilla, 0x00B8, 
 GDK_space, 0x02DB, 
+GDK_nobreakspace, 0x0328, 
+GDK_Omacron, 0x01EC, 
+GDK_omacron, 0x01ED, 
 GDK_dead_ogonek, 0x02DB, 
 GDK_space, 0x037A, 
 GDK_Greek_alphaaccent, 0x1FB4, 
@@ -969,8 +1112,45 @@ GDK_Multi_key, GDK_plus, GDK_O, 0x1EE2, 
 GDK_Multi_key, GDK_plus, GDK_U, 0x1EF0, 
 GDK_Multi_key, GDK_plus, GDK_o, 0x1EE3, 
 GDK_Multi_key, GDK_plus, GDK_u, 0x1EF1, 
+GDK_space, 0x0309, 
+GDK_B, 0x0181, 
+GDK_C, 0x0187, 
+GDK_D, 0x018A, 
+GDK_F, 0x0191, 
+GDK_G, 0x0193, 
+GDK_K, 0x0198, 
+GDK_M, 0x2C6E, 
+GDK_N, 0x019D, 
+GDK_P, 0x01A4, 
+GDK_T, 0x01AC, 
+GDK_V, 0x01B2, 
+GDK_W, 0x2C72, 
+GDK_Z, 0x0224, 
+GDK_b, 0x0253, 
+GDK_c, 0x0188, 
+GDK_d, 0x0257, 
+GDK_f, 0x0192, 
+GDK_g, 0x0260, 
+GDK_h, 0x0266, 
+GDK_k, 0x0199, 
+GDK_m, 0x0271, 
+GDK_n, 0x0272, 
+GDK_p, 0x01A5, 
+GDK_q, 0x02A0, 
+GDK_s, 0x0282, 
+GDK_t, 0x01AD, 
+GDK_v, 0x028B, 
+GDK_w, 0x2C73, 
+GDK_z, 0x0225, 
+GDK_nobreakspace, 0x0309, 
 GDK_Abreve, 0x1EB2, 
 GDK_abreve, 0x1EB3, 
+0x0256, 0x1D91, 
+GDK_schwa, 0x025A, 
+0x025C, 0x025D, 
+0x025F, 0x0284, 
+0x0279, 0x027B, 
+GDK_dead_hook, 0x0309, 
 GDK_Multi_key, GDK_plus, GDK_O, 0x1EDE, 
 GDK_Multi_key, GDK_plus, GDK_U, 0x1EEC, 
 GDK_Multi_key, GDK_plus, GDK_o, 0x1EDF, 
@@ -1017,9 +1197,11 @@ GDK_Greek_upsilon, 0x1F51, 
 GDK_Greek_omega, 0x1F61, 
 GDK_space, GDK_space, 0x00A0, 
 GDK_space, GDK_apostrophe, 0x0027, 
+GDK_space, GDK_parenleft, 0x02D8, 
 GDK_space, GDK_comma, 0x00B8, 
 GDK_space, GDK_minus, 0x007E, 
 GDK_space, GDK_period, 0x2008, 
+GDK_space, GDK_less, 0x02C7, 
 GDK_space, GDK_greater, 0x005E, 
 GDK_space, GDK_asciicircum, 0x005E, 
 GDK_space, GDK_grave, 0x0060, 
@@ -1037,8 +1219,9 @@ GDK_exclam, GDK_L, 0x1E36, 
 GDK_exclam, GDK_M, 0x1E42, 
 GDK_exclam, GDK_N, 0x1E46, 
 GDK_exclam, GDK_O, 0x1ECC, 
+GDK_exclam, GDK_P, 0x00B6, 
 GDK_exclam, GDK_R, 0x1E5A, 
-GDK_exclam, GDK_S, 0x1E62, 
+GDK_exclam, GDK_S, 0x00A7, 
 GDK_exclam, GDK_T, 0x1E6C, 
 GDK_exclam, GDK_U, 0x1EE4, 
 GDK_exclam, GDK_V, 0x1E7E, 
@@ -1057,8 +1240,9 @@ GDK_exclam, GDK_l, 0x1E37, 
 GDK_exclam, GDK_m, 0x1E43, 
 GDK_exclam, GDK_n, 0x1E47, 
 GDK_exclam, GDK_o, 0x1ECD, 
+GDK_exclam, GDK_p, 0x00B6, 
 GDK_exclam, GDK_r, 0x1E5B, 
-GDK_exclam, GDK_s, 0x1E63, 
+GDK_exclam, GDK_s, 0x00A7, 
 GDK_exclam, GDK_t, 0x1E6D, 
 GDK_exclam, GDK_u, 0x1EE5, 
 GDK_exclam, GDK_v, 0x1E7F, 
@@ -1069,6 +1253,7 @@ GDK_exclam, GDK_Ohorn, 0x1EE2, 
 GDK_exclam, GDK_ohorn, 0x1EE3, 
 GDK_exclam, GDK_Uhorn, 0x1EF0, 
 GDK_exclam, GDK_uhorn, 0x1EF1, 
+GDK_quotedbl, GDK_quotedbl, 0x00A8, 
 GDK_quotedbl, GDK_apostrophe, 0x0344, 
 GDK_quotedbl, GDK_comma, 0x201E, 
 GDK_quotedbl, GDK_slash, 0x301E, 
@@ -1136,6 +1321,7 @@ GDK_numbersign, GDK_b, 0x266D, 
 GDK_numbersign, GDK_f, 0x266E, 
 GDK_percent, GDK_o, 0x2030, 
 GDK_apostrophe, GDK_space, 0x0027, 
+GDK_apostrophe, GDK_apostrophe, 0x00B4, 
 GDK_apostrophe, GDK_comma, 0x201A, 
 GDK_apostrophe, GDK_less, 0x2018, 
 GDK_apostrophe, GDK_greater, 0x2019, 
@@ -1252,8 +1438,15 @@ GDK_apostrophe, 0x1F60, 0x1F64, 
 GDK_apostrophe, 0x1F61, 0x1F65, 
 GDK_apostrophe, 0x1F68, 0x1F6C, 
 GDK_apostrophe, 0x1F69, 0x1F6D, 
+GDK_parenleft, GDK_space, 0x02D8, 
 GDK_parenleft, GDK_parenleft, 0x005B, 
 GDK_parenleft, GDK_minus, 0x007B, 
+GDK_parenleft, GDK_A, 0x0102, 
+GDK_parenleft, GDK_G, 0x011E, 
+GDK_parenleft, GDK_a, 0x0103, 
+GDK_parenleft, GDK_c, 0x00A9, 
+GDK_parenleft, GDK_g, 0x011F, 
+GDK_parenleft, GDK_r, 0x00AE, 
 GDK_parenleft, GDK_Greek_ALPHA, 0x1F09, 
 GDK_parenleft, GDK_Greek_EPSILON, 0x1F19, 
 GDK_parenleft, GDK_Greek_ETA, 0x1F29, 
@@ -1286,6 +1479,11 @@ GDK_parenright, GDK_Greek_omicron, 0x1F4
 GDK_parenright, GDK_Greek_rho, 0x1FE4, 
 GDK_parenright, GDK_Greek_upsilon, 0x1F50, 
 GDK_parenright, GDK_Greek_omega, 0x1F60, 
+GDK_asterisk, GDK_0, 0x00B0, 
+GDK_asterisk, GDK_A, 0x00C5, 
+GDK_asterisk, GDK_U, 0x016E, 
+GDK_asterisk, GDK_a, 0x00E5, 
+GDK_asterisk, GDK_u, 0x016F, 
 GDK_plus, GDK_plus, 0x0023, 
 GDK_plus, GDK_minus, 0x00B1, 
 GDK_plus, GDK_O, 0x01A0, 
@@ -1295,39 +1493,63 @@ GDK_plus, GDK_u, 0x01B0, 
 GDK_comma, GDK_space, 0x00B8, 
 GDK_comma, GDK_quotedbl, 0x201E, 
 GDK_comma, GDK_apostrophe, 0x201A, 
+GDK_comma, GDK_comma, 0x00B8, 
 GDK_comma, GDK_minus, 0x00AC, 
+GDK_comma, GDK_A, 0x0104, 
 GDK_comma, GDK_C, 0x00C7, 
 GDK_comma, GDK_D, 0x1E10, 
-GDK_comma, GDK_E, 0x0228, 
+GDK_comma, GDK_E, 0x0118, 
 GDK_comma, GDK_G, 0x0122, 
 GDK_comma, GDK_H, 0x1E28, 
+GDK_comma, GDK_I, 0x012E, 
 GDK_comma, GDK_K, 0x0136, 
 GDK_comma, GDK_L, 0x013B, 
 GDK_comma, GDK_N, 0x0145, 
 GDK_comma, GDK_R, 0x0156, 
 GDK_comma, GDK_S, 0x015E, 
 GDK_comma, GDK_T, 0x0162, 
+GDK_comma, GDK_U, 0x0172, 
+GDK_comma, GDK_a, 0x0105, 
 GDK_comma, GDK_c, 0x00E7, 
 GDK_comma, GDK_d, 0x1E11, 
-GDK_comma, GDK_e, 0x0229, 
+GDK_comma, GDK_e, 0x0119, 
 GDK_comma, GDK_g, 0x0123, 
 GDK_comma, GDK_h, 0x1E29, 
+GDK_comma, GDK_i, 0x012F, 
 GDK_comma, GDK_k, 0x0137, 
 GDK_comma, GDK_l, 0x013C, 
 GDK_comma, GDK_n, 0x0146, 
 GDK_comma, GDK_r, 0x0157, 
 GDK_comma, GDK_s, 0x015F, 
 GDK_comma, GDK_t, 0x0163, 
+GDK_comma, GDK_u, 0x0173, 
 GDK_minus, GDK_space, 0x007E, 
 GDK_minus, GDK_parenleft, 0x007B, 
 GDK_minus, GDK_parenright, 0x007D, 
+GDK_minus, GDK_plus, 0x00B1, 
 GDK_minus, GDK_comma, 0x00AC, 
 GDK_minus, GDK_colon, 0x00F7, 
+GDK_minus, GDK_A, 0x00C3, 
 GDK_minus, GDK_D, 0x0110, 
+GDK_minus, GDK_E, 0x0112, 
+GDK_minus, GDK_I, 0x012A, 
 GDK_minus, GDK_L, 0x00A3, 
+GDK_minus, GDK_N, 0x00D1, 
+GDK_minus, GDK_O, 0x00D5, 
+GDK_minus, GDK_U, 0x016A, 
+GDK_minus, GDK_Y, 0x00A5, 
+GDK_minus, GDK_asciicircum, 0x00AF, 
+GDK_minus, GDK_a, 0x00E3, 
 GDK_minus, GDK_d, 0x0111, 
+GDK_minus, GDK_e, 0x0113, 
+GDK_minus, GDK_i, 0x012B, 
+GDK_minus, GDK_l, 0x00A3, 
+GDK_minus, GDK_n, 0x00F1, 
+GDK_minus, GDK_o, 0x00F5, 
+GDK_minus, GDK_u, 0x016B, 
+GDK_minus, GDK_y, 0x00A5, 
 GDK_period, GDK_minus, 0x00B7, 
-GDK_period, GDK_period, 0x2026, 
+GDK_period, GDK_period, 0x02D9, 
 GDK_period, GDK_less, 0x2039, 
 GDK_period, GDK_equal, 0x2022, 
 GDK_period, GDK_greater, 0x203A, 
@@ -1351,6 +1573,7 @@ GDK_period, GDK_W, 0x1E86, 
 GDK_period, GDK_X, 0x1E8A, 
 GDK_period, GDK_Y, 0x1E8E, 
 GDK_period, GDK_Z, 0x017B, 
+GDK_period, GDK_asciicircum, 0x00B7, 
 GDK_period, GDK_a, 0x0227, 
 GDK_period, GDK_b, 0x1E03, 
 GDK_period, GDK_c, 0x010B, 
@@ -1359,6 +1582,7 @@ GDK_period, GDK_e, 0x0117, 
 GDK_period, GDK_f, 0x1E1F, 
 GDK_period, GDK_g, 0x0121, 
 GDK_period, GDK_h, 0x1E23, 
+GDK_period, GDK_i, 0x0131, 
 GDK_period, GDK_m, 0x1E41, 
 GDK_period, GDK_n, 0x1E45, 
 GDK_period, GDK_o, 0x022F, 
@@ -1379,7 +1603,7 @@ GDK_period, 0x1E62, 0x1E68, 
 GDK_period, 0x1E63, 0x1E69, 
 GDK_slash, GDK_slash, 0x005C, 
 GDK_slash, GDK_less, 0x005C, 
-GDK_slash, GDK_C, 0x20A1, 
+GDK_slash, GDK_C, 0x00A2, 
 GDK_slash, GDK_D, 0x0110, 
 GDK_slash, GDK_G, 0x01E4, 
 GDK_slash, GDK_H, 0x0126, 
@@ -1387,6 +1611,7 @@ GDK_slash, GDK_I, 0x0197, 
 GDK_slash, GDK_L, 0x0141, 
 GDK_slash, GDK_O, 0x00D8, 
 GDK_slash, GDK_T, 0x0166, 
+GDK_slash, GDK_U, 0x00B5, 
 GDK_slash, GDK_Z, 0x01B5, 
 GDK_slash, GDK_asciicircum, 0x007C, 
 GDK_slash, GDK_b, 0x0180, 
@@ -1399,6 +1624,7 @@ GDK_slash, GDK_l, 0x0142, 
 GDK_slash, GDK_m, 0x20A5, 
 GDK_slash, GDK_o, 0x00F8, 
 GDK_slash, GDK_t, 0x0167, 
+GDK_slash, GDK_u, 0x00B5, 
 GDK_slash, GDK_z, 0x01B6, 
 GDK_slash, 0x0294, 0x02A1, 
 GDK_slash, 0x04AE, 0x04B0, 
@@ -1410,17 +1636,34 @@ GDK_slash, GDK_Cyrillic_KA, 0x049E, 
 GDK_slash, GDK_leftarrow, 0x219A, 
 GDK_slash, GDK_rightarrow, 0x219B, 
 GDK_slash, 0x2194, 0x21AE, 
+GDK_0, GDK_asterisk, 0x00B0, 
+GDK_0, GDK_C, 0x00A9, 
+GDK_0, GDK_S, 0x00A7, 
+GDK_0, GDK_X, 0x00A4, 
+GDK_0, GDK_asciicircum, 0x00B0, 
+GDK_0, GDK_c, 0x00A9, 
+GDK_0, GDK_s, 0x00A7, 
+GDK_0, GDK_x, 0x00A4, 
 GDK_1, GDK_2, 0x00BD, 
 GDK_1, GDK_3, 0x2153, 
 GDK_1, GDK_4, 0x00BC, 
 GDK_1, GDK_5, 0x2155, 
 GDK_1, GDK_6, 0x2159, 
 GDK_1, GDK_8, 0x215B, 
+GDK_1, GDK_S, 0x00B9, 
+GDK_1, GDK_asciicircum, 0x00B9, 
+GDK_1, GDK_s, 0x00B9, 
 GDK_2, GDK_3, 0x2154, 
 GDK_2, GDK_5, 0x2156, 
+GDK_2, GDK_S, 0x00B2, 
+GDK_2, GDK_asciicircum, 0x00B2, 
+GDK_2, GDK_s, 0x00B2, 
 GDK_3, GDK_4, 0x00BE, 
 GDK_3, GDK_5, 0x2157, 
 GDK_3, GDK_8, 0x215C, 
+GDK_3, GDK_S, 0x00B3, 
+GDK_3, GDK_asciicircum, 0x00B3, 
+GDK_3, GDK_s, 0x00B3, 
 GDK_4, GDK_5, 0x2158, 
 GDK_5, GDK_6, 0x215A, 
 GDK_5, GDK_8, 0x215D, 
@@ -1436,14 +1679,33 @@ GDK_semicolon, GDK_e, 0x0119, 
 GDK_semicolon, GDK_i, 0x012F, 
 GDK_semicolon, GDK_o, 0x01EB, 
 GDK_semicolon, GDK_u, 0x0173, 
+GDK_less, GDK_space, 0x02C7, 
 GDK_less, GDK_quotedbl, 0x201C, 
 GDK_less, GDK_apostrophe, 0x2018, 
 GDK_less, GDK_slash, 0x005C, 
 GDK_less, GDK_less, 0x00AB, 
+GDK_less, GDK_C, 0x010C, 
+GDK_less, GDK_D, 0x010E, 
+GDK_less, GDK_E, 0x011A, 
+GDK_less, GDK_L, 0x013D, 
+GDK_less, GDK_N, 0x0147, 
+GDK_less, GDK_R, 0x0158, 
+GDK_less, GDK_S, 0x0160, 
+GDK_less, GDK_T, 0x0164, 
+GDK_less, GDK_Z, 0x017D, 
+GDK_less, GDK_c, 0x010D, 
+GDK_less, GDK_d, 0x010F, 
+GDK_less, GDK_e, 0x011B, 
+GDK_less, GDK_l, 0x013E, 
+GDK_less, GDK_n, 0x0148, 
+GDK_less, GDK_r, 0x0159, 
+GDK_less, GDK_s, 0x0161, 
+GDK_less, GDK_t, 0x0165, 
+GDK_less, GDK_z, 0x017E, 
 GDK_less, 0x0338, 0x226E, 
 GDK_equal, GDK_C, 0x20AC, 
 GDK_equal, GDK_E, 0x20AC, 
-GDK_equal, GDK_L, 0x20A4, 
+GDK_equal, GDK_L, 0x00A3, 
 GDK_equal, GDK_N, 0x20A6, 
 GDK_equal, GDK_O, 0x0150, 
 GDK_equal, GDK_U, 0x0170, 
@@ -1451,8 +1713,10 @@ GDK_equal, GDK_W, 0x20A9, 
 GDK_equal, GDK_Y, 0x00A5, 
 GDK_equal, GDK_c, 0x20AC, 
 GDK_equal, GDK_e, 0x20AC, 
+GDK_equal, GDK_l, 0x00A3, 
 GDK_equal, GDK_o, 0x0151, 
 GDK_equal, GDK_u, 0x0171, 
+GDK_equal, GDK_y, 0x00A5, 
 GDK_equal, 0x0338, 0x2260, 
 GDK_equal, GDK_Cyrillic_u, 0x04F3, 
 GDK_equal, GDK_Cyrillic_IE, 0x20AC, 
@@ -1462,6 +1726,16 @@ GDK_greater, GDK_space, 0x005E, 
 GDK_greater, GDK_quotedbl, 0x201D, 
 GDK_greater, GDK_apostrophe, 0x2019, 
 GDK_greater, GDK_greater, 0x00BB, 
+GDK_greater, GDK_A, 0x00C2, 
+GDK_greater, GDK_E, 0x00CA, 
+GDK_greater, GDK_I, 0x00CE, 
+GDK_greater, GDK_O, 0x00D4, 
+GDK_greater, GDK_U, 0x00DB, 
+GDK_greater, GDK_a, 0x00E2, 
+GDK_greater, GDK_e, 0x00EA, 
+GDK_greater, GDK_i, 0x00EE, 
+GDK_greater, GDK_o, 0x00F4, 
+GDK_greater, GDK_u, 0x00FB, 
 GDK_greater, 0x0338, 0x226F, 
 GDK_question, GDK_exclam, 0x203D, 
 GDK_question, GDK_question, 0x00BF, 
@@ -1489,48 +1763,162 @@ GDK_question, GDK_Uhorn, 0x1EEC, 
 GDK_question, GDK_uhorn, 0x1EED, 
 GDK_question, GDK_Abreve, 0x1EB2, 
 GDK_question, GDK_abreve, 0x1EB3, 
+GDK_A, GDK_quotedbl, 0x00C4, 
+GDK_A, GDK_apostrophe, 0x00C1, 
+GDK_A, GDK_parenleft, 0x0102, 
+GDK_A, GDK_asterisk, 0x00C5, 
+GDK_A, GDK_comma, 0x0104, 
+GDK_A, GDK_minus, 0x00C3, 
+GDK_A, GDK_greater, 0x00C2, 
+GDK_A, GDK_A, 0x00C5, 
 GDK_A, GDK_E, 0x00C6, 
 GDK_A, GDK_T, 0x0040, 
-GDK_C, GDK_slash, 0x20A1, 
+GDK_A, GDK_asciicircum, 0x00C2, 
+GDK_A, GDK_underscore, 0x00AA, 
+GDK_A, GDK_grave, 0x00C0, 
+GDK_A, GDK_asciitilde, 0x00C3, 
+GDK_A, GDK_diaeresis, 0x00C4, 
+GDK_A, GDK_acute, 0x00C1, 
+GDK_B, GDK_period, 0x1E02, 
+GDK_C, GDK_apostrophe, 0x0106, 
+GDK_C, GDK_comma, 0x00C7, 
+GDK_C, GDK_period, 0x010A, 
+GDK_C, GDK_slash, 0x00A2, 
+GDK_C, GDK_0, 0x00A9, 
+GDK_C, GDK_less, 0x010C, 
 GDK_C, GDK_equal, 0x20AC, 
 GDK_C, GDK_E, 0x20A0, 
+GDK_C, GDK_O, 0x00A9, 
+GDK_C, GDK_o, 0x00A9, 
 GDK_C, GDK_r, 0x20A2, 
+GDK_C, GDK_bar, 0x00A2, 
+GDK_D, GDK_minus, 0x0110, 
+GDK_D, GDK_period, 0x1E0A, 
+GDK_D, GDK_less, 0x010E, 
 GDK_D, GDK_H, 0x00D0, 
+GDK_E, GDK_quotedbl, 0x00CB, 
+GDK_E, GDK_apostrophe, 0x00C9, 
+GDK_E, GDK_comma, 0x0118, 
+GDK_E, GDK_minus, 0x0112, 
+GDK_E, GDK_period, 0x0116, 
+GDK_E, GDK_less, 0x011A, 
 GDK_E, GDK_equal, 0x20AC, 
+GDK_E, GDK_greater, 0x00CA, 
+GDK_E, GDK_asciicircum, 0x00CA, 
+GDK_E, GDK_underscore, 0x0112, 
+GDK_E, GDK_grave, 0x00C8, 
+GDK_E, GDK_diaeresis, 0x00CB, 
+GDK_E, GDK_acute, 0x00C9, 
+GDK_F, GDK_period, 0x1E1E, 
 GDK_F, GDK_r, 0x20A3, 
+GDK_G, GDK_parenleft, 0x011E, 
+GDK_G, GDK_comma, 0x0122, 
+GDK_G, GDK_period, 0x0120, 
+GDK_G, GDK_U, 0x011E, 
+GDK_G, GDK_breve, 0x011E, 
+GDK_I, GDK_quotedbl, 0x00CF, 
+GDK_I, GDK_apostrophe, 0x00CD, 
+GDK_I, GDK_comma, 0x012E, 
+GDK_I, GDK_minus, 0x012A, 
+GDK_I, GDK_period, 0x0130, 
+GDK_I, GDK_greater, 0x00CE, 
+GDK_I, GDK_asciicircum, 0x00CE, 
+GDK_I, GDK_underscore, 0x012A, 
+GDK_I, GDK_grave, 0x00CC, 
+GDK_I, GDK_asciitilde, 0x0128, 
+GDK_I, GDK_diaeresis, 0x00CF, 
+GDK_I, GDK_acute, 0x00CD, 
+GDK_K, GDK_comma, 0x0136, 
+GDK_L, GDK_apostrophe, 0x0139, 
+GDK_L, GDK_comma, 0x013B, 
 GDK_L, GDK_minus, 0x00A3, 
-GDK_L, GDK_equal, 0x20A4, 
+GDK_L, GDK_slash, 0x0141, 
+GDK_L, GDK_less, 0x013D, 
+GDK_L, GDK_equal, 0x00A3, 
 GDK_L, GDK_V, 0x007C, 
+GDK_M, GDK_period, 0x1E40, 
+GDK_N, GDK_apostrophe, 0x0143, 
+GDK_N, GDK_comma, 0x0145, 
+GDK_N, GDK_minus, 0x00D1, 
+GDK_N, GDK_less, 0x0147, 
 GDK_N, GDK_equal, 0x20A6, 
 GDK_N, GDK_G, 0x014A, 
 GDK_N, GDK_O, 0x2116, 
 GDK_N, GDK_o, 0x2116, 
+GDK_N, GDK_asciitilde, 0x00D1, 
+GDK_O, GDK_quotedbl, 0x00D6, 
+GDK_O, GDK_apostrophe, 0x00D3, 
+GDK_O, GDK_minus, 0x00D5, 
+GDK_O, GDK_slash, 0x00D8, 
+GDK_O, GDK_greater, 0x00D4, 
 GDK_O, GDK_C, 0x00A9, 
 GDK_O, GDK_E, 0x0152, 
 GDK_O, GDK_R, 0x00AE, 
+GDK_O, GDK_S, 0x00A7, 
+GDK_O, GDK_X, 0x00A4, 
+GDK_O, GDK_asciicircum, 0x00D4, 
+GDK_O, GDK_underscore, 0x00BA, 
+GDK_O, GDK_grave, 0x00D2, 
 GDK_O, GDK_c, 0x00A9, 
 GDK_O, GDK_r, 0x00AE, 
+GDK_O, GDK_x, 0x00A4, 
+GDK_O, GDK_asciitilde, 0x00D5, 
+GDK_O, GDK_diaeresis, 0x00D6, 
+GDK_O, GDK_acute, 0x00D3, 
 GDK_P, GDK_exclam, 0x00B6, 
+GDK_P, GDK_period, 0x1E56, 
 GDK_P, GDK_P, 0x00B6, 
 GDK_P, GDK_t, 0x20A7, 
+GDK_R, GDK_apostrophe, 0x0154, 
+GDK_R, GDK_comma, 0x0156, 
+GDK_R, GDK_less, 0x0158, 
+GDK_R, GDK_O, 0x00AE, 
 GDK_R, GDK_s, 0x20A8, 
+GDK_S, GDK_exclam, 0x00A7, 
+GDK_S, GDK_apostrophe, 0x015A, 
+GDK_S, GDK_comma, 0x015E, 
+GDK_S, GDK_period, 0x1E60, 
+GDK_S, GDK_0, 0x00A7, 
+GDK_S, GDK_1, 0x00B9, 
+GDK_S, GDK_2, 0x00B2, 
+GDK_S, GDK_3, 0x00B3, 
+GDK_S, GDK_less, 0x0160, 
 GDK_S, GDK_M, 0x2120, 
+GDK_S, GDK_O, 0x00A7, 
 GDK_S, GDK_m, 0x2120, 
+GDK_S, GDK_cedilla, 0x015E, 
+GDK_T, GDK_minus, 0x0166, 
+GDK_T, GDK_period, 0x1E6A, 
+GDK_T, GDK_slash, 0x0166, 
+GDK_T, GDK_less, 0x0164, 
 GDK_T, GDK_H, 0x00DE, 
 GDK_T, GDK_M, 0x2122, 
 GDK_T, GDK_m, 0x2122, 
+GDK_U, GDK_quotedbl, 0x00DC, 
+GDK_U, GDK_apostrophe, 0x00DA, 
+GDK_U, GDK_asterisk, 0x016E, 
+GDK_U, GDK_comma, 0x0172, 
+GDK_U, GDK_minus, 0x016A, 
+GDK_U, GDK_slash, 0x00B5, 
+GDK_U, GDK_greater, 0x00DB, 
 GDK_U, GDK_A, 0x0102, 
 GDK_U, GDK_E, 0x0114, 
 GDK_U, GDK_G, 0x011E, 
 GDK_U, GDK_I, 0x012C, 
 GDK_U, GDK_O, 0x014E, 
 GDK_U, GDK_U, 0x016C, 
+GDK_U, GDK_asciicircum, 0x00DB, 
+GDK_U, GDK_underscore, 0x016A, 
+GDK_U, GDK_grave, 0x00D9, 
 GDK_U, GDK_a, 0x0103, 
 GDK_U, GDK_e, 0x0115, 
 GDK_U, GDK_g, 0x011F, 
 GDK_U, GDK_i, 0x012D, 
 GDK_U, GDK_o, 0x014F, 
 GDK_U, GDK_u, 0x016D, 
+GDK_U, GDK_asciitilde, 0x0168, 
+GDK_U, GDK_diaeresis, 0x00DC, 
+GDK_U, GDK_acute, 0x00DA, 
 GDK_U, 0x0228, 0x1E1C, 
 GDK_U, 0x0229, 0x1E1D, 
 GDK_U, GDK_Cyrillic_a, 0x04D1, 
@@ -1553,13 +1941,28 @@ GDK_U, 0x1EA0, 0x1EB6, 
 GDK_U, 0x1EA1, 0x1EB7, 
 GDK_V, GDK_L, 0x007C, 
 GDK_W, GDK_equal, 0x20A9, 
+GDK_W, GDK_asciicircum, 0x0174, 
+GDK_X, GDK_0, 0x00A4, 
+GDK_X, GDK_O, 0x00A4, 
+GDK_X, GDK_o, 0x00A4, 
+GDK_Y, GDK_quotedbl, 0x0178, 
+GDK_Y, GDK_apostrophe, 0x00DD, 
+GDK_Y, GDK_minus, 0x00A5, 
 GDK_Y, GDK_equal, 0x00A5, 
+GDK_Y, GDK_asciicircum, 0x0176, 
+GDK_Y, GDK_diaeresis, 0x0178, 
+GDK_Y, GDK_acute, 0x00DD, 
+GDK_Z, GDK_apostrophe, 0x0179, 
+GDK_Z, GDK_period, 0x017B, 
+GDK_Z, GDK_less, 0x017D, 
 GDK_asciicircum, GDK_space, 0x005E, 
 GDK_asciicircum, GDK_parenleft, 0x207D, 
 GDK_asciicircum, GDK_parenright, 0x207E, 
 GDK_asciicircum, GDK_plus, 0x207A, 
+GDK_asciicircum, GDK_minus, 0x00AF, 
+GDK_asciicircum, GDK_period, 0x00B7, 
 GDK_asciicircum, GDK_slash, 0x007C, 
-GDK_asciicircum, GDK_0, 0x2070, 
+GDK_asciicircum, GDK_0, 0x00B0, 
 GDK_asciicircum, GDK_1, 0x00B9, 
 GDK_asciicircum, GDK_2, 0x00B2, 
 GDK_asciicircum, GDK_3, 0x00B3, 
@@ -1583,6 +1986,7 @@ GDK_asciicircum, GDK_U, 0x00DB, 
 GDK_asciicircum, GDK_W, 0x0174, 
 GDK_asciicircum, GDK_Y, 0x0176, 
 GDK_asciicircum, GDK_Z, 0x1E90, 
+GDK_asciicircum, GDK_underscore, 0x00AF, 
 GDK_asciicircum, GDK_a, 0x00E2, 
 GDK_asciicircum, GDK_c, 0x0109, 
 GDK_asciicircum, GDK_e, 0x00EA, 
@@ -1644,18 +2048,20 @@ GDK_underscore, GDK_7, 0x2087, 
 GDK_underscore, GDK_8, 0x2088, 
 GDK_underscore, GDK_9, 0x2089, 
 GDK_underscore, GDK_equal, 0x208C, 
-GDK_underscore, GDK_A, 0x0100, 
+GDK_underscore, GDK_A, 0x00AA, 
 GDK_underscore, GDK_E, 0x0112, 
 GDK_underscore, GDK_G, 0x1E20, 
 GDK_underscore, GDK_I, 0x012A, 
-GDK_underscore, GDK_O, 0x014C, 
+GDK_underscore, GDK_O, 0x00BA, 
 GDK_underscore, GDK_U, 0x016A, 
 GDK_underscore, GDK_Y, 0x0232, 
-GDK_underscore, GDK_a, 0x0101, 
+GDK_underscore, GDK_asciicircum, 0x00AF, 
+GDK_underscore, GDK_underscore, 0x00AF, 
+GDK_underscore, GDK_a, 0x00AA, 
 GDK_underscore, GDK_e, 0x0113, 
 GDK_underscore, GDK_g, 0x1E21, 
 GDK_underscore, GDK_i, 0x012B, 
-GDK_underscore, GDK_o, 0x014D, 
+GDK_underscore, GDK_o, 0x00BA, 
 GDK_underscore, GDK_u, 0x016B, 
 GDK_underscore, GDK_y, 0x0233, 
 GDK_underscore, GDK_Adiaeresis, 0x01DE, 
@@ -1784,7 +2190,22 @@ GDK_grave, 0x1F60, 0x1F62, 
 GDK_grave, 0x1F61, 0x1F63, 
 GDK_grave, 0x1F68, 0x1F6A, 
 GDK_grave, 0x1F69, 0x1F6B, 
+GDK_a, GDK_quotedbl, 0x00E4, 
+GDK_a, GDK_apostrophe, 0x00E1, 
+GDK_a, GDK_parenleft, 0x0103, 
+GDK_a, GDK_asterisk, 0x00E5, 
+GDK_a, GDK_comma, 0x0105, 
+GDK_a, GDK_minus, 0x00E3, 
+GDK_a, GDK_greater, 0x00E2, 
+GDK_a, GDK_asciicircum, 0x00E2, 
+GDK_a, GDK_underscore, 0x00AA, 
+GDK_a, GDK_grave, 0x00E0, 
+GDK_a, GDK_a, 0x00E5, 
 GDK_a, GDK_e, 0x00E6, 
+GDK_a, GDK_asciitilde, 0x00E3, 
+GDK_a, GDK_diaeresis, 0x00E4, 
+GDK_a, GDK_acute, 0x00E1, 
+GDK_b, GDK_period, 0x1E03, 
 GDK_b, GDK_A, 0x0102, 
 GDK_b, GDK_E, 0x0114, 
 GDK_b, GDK_G, 0x011E, 
@@ -1817,7 +2238,12 @@ GDK_b, GDK_Greek_iota, 0x1FD0, 
 GDK_b, GDK_Greek_upsilon, 0x1FE0, 
 GDK_b, 0x1EA0, 0x1EB6, 
 GDK_b, 0x1EA1, 0x1EB7, 
+GDK_c, GDK_apostrophe, 0x0107, 
+GDK_c, GDK_comma, 0x00E7, 
+GDK_c, GDK_period, 0x010B, 
 GDK_c, GDK_slash, 0x00A2, 
+GDK_c, GDK_0, 0x00A9, 
+GDK_c, GDK_less, 0x010D, 
 GDK_c, GDK_equal, 0x20AC, 
 GDK_c, GDK_A, 0x01CD, 
 GDK_c, GDK_C, 0x010C, 
@@ -1829,7 +2255,7 @@ GDK_c, GDK_I, 0x01CF, 
 GDK_c, GDK_K, 0x01E8, 
 GDK_c, GDK_L, 0x013D, 
 GDK_c, GDK_N, 0x0147, 
-GDK_c, GDK_O, 0x01D1, 
+GDK_c, GDK_O, 0x00A9, 
 GDK_c, GDK_R, 0x0158, 
 GDK_c, GDK_S, 0x0160, 
 GDK_c, GDK_T, 0x0164, 
@@ -1846,7 +2272,7 @@ GDK_c, GDK_j, 0x01F0, 
 GDK_c, GDK_k, 0x01E9, 
 GDK_c, GDK_l, 0x013E, 
 GDK_c, GDK_n, 0x0148, 
-GDK_c, GDK_o, 0x01D2, 
+GDK_c, GDK_o, 0x00A9, 
 GDK_c, GDK_r, 0x0159, 
 GDK_c, GDK_s, 0x0161, 
 GDK_c, GDK_t, 0x0165, 
@@ -1857,22 +2283,75 @@ GDK_c, 0x00DC, 0x01D9, 
 GDK_c, GDK_udiaeresis, 0x01DA, 
 GDK_c, 0x01B7, 0x01EE, 
 GDK_c, 0x0292, 0x01EF, 
-GDK_d, GDK_minus, 0x20AB, 
+GDK_d, GDK_minus, 0x0111, 
+GDK_d, GDK_period, 0x1E0B, 
+GDK_d, GDK_less, 0x010F, 
 GDK_d, GDK_h, 0x00F0, 
+GDK_e, GDK_quotedbl, 0x00EB, 
+GDK_e, GDK_apostrophe, 0x00E9, 
+GDK_e, GDK_comma, 0x0119, 
+GDK_e, GDK_minus, 0x0113, 
+GDK_e, GDK_period, 0x0117, 
+GDK_e, GDK_less, 0x011B, 
 GDK_e, GDK_equal, 0x20AC, 
+GDK_e, GDK_greater, 0x00EA, 
+GDK_e, GDK_asciicircum, 0x00EA, 
+GDK_e, GDK_underscore, 0x0113, 
+GDK_e, GDK_grave, 0x00E8, 
 GDK_e, GDK_e, 0x0259, 
+GDK_e, GDK_diaeresis, 0x00EB, 
+GDK_e, GDK_acute, 0x00E9, 
+GDK_f, GDK_period, 0x1E1F, 
 GDK_f, GDK_S, 0x017F, 
 GDK_f, GDK_s, 0x017F, 
+GDK_g, GDK_parenleft, 0x011F, 
+GDK_g, GDK_comma, 0x0123, 
+GDK_g, GDK_period, 0x0121, 
+GDK_g, GDK_U, 0x011F, 
+GDK_g, GDK_breve, 0x011F, 
+GDK_i, GDK_quotedbl, 0x00EF, 
+GDK_i, GDK_apostrophe, 0x00ED, 
+GDK_i, GDK_comma, 0x012F, 
+GDK_i, GDK_minus, 0x012B, 
 GDK_i, GDK_period, 0x0131, 
+GDK_i, GDK_greater, 0x00EE, 
+GDK_i, GDK_asciicircum, 0x00EE, 
+GDK_i, GDK_underscore, 0x012B, 
+GDK_i, GDK_grave, 0x00EC, 
+GDK_i, GDK_asciitilde, 0x0129, 
+GDK_i, GDK_diaeresis, 0x00EF, 
+GDK_i, GDK_acute, 0x00ED, 
+GDK_k, GDK_comma, 0x0137, 
 GDK_k, GDK_k, 0x0138, 
+GDK_l, GDK_apostrophe, 0x013A, 
+GDK_l, GDK_comma, 0x013C, 
+GDK_l, GDK_minus, 0x00A3, 
+GDK_l, GDK_slash, 0x0142, 
+GDK_l, GDK_less, 0x013E, 
+GDK_l, GDK_equal, 0x00A3, 
 GDK_l, GDK_v, 0x007C, 
+GDK_m, GDK_period, 0x1E41, 
 GDK_m, GDK_slash, 0x20A5, 
 GDK_m, GDK_u, 0x00B5, 
+GDK_n, GDK_apostrophe, 0x0144, 
+GDK_n, GDK_comma, 0x0146, 
+GDK_n, GDK_minus, 0x00F1, 
+GDK_n, GDK_less, 0x0148, 
 GDK_n, GDK_g, 0x014B, 
+GDK_n, GDK_asciitilde, 0x00F1, 
+GDK_o, GDK_quotedbl, 0x00F6, 
+GDK_o, GDK_apostrophe, 0x00F3, 
+GDK_o, GDK_minus, 0x00F5, 
+GDK_o, GDK_slash, 0x00F8, 
+GDK_o, GDK_greater, 0x00F4, 
 GDK_o, GDK_A, 0x00C5, 
 GDK_o, GDK_C, 0x00A9, 
 GDK_o, GDK_R, 0x00AE, 
 GDK_o, GDK_U, 0x016E, 
+GDK_o, GDK_X, 0x00A4, 
+GDK_o, GDK_asciicircum, 0x00F4, 
+GDK_o, GDK_underscore, 0x00BA, 
+GDK_o, GDK_grave, 0x00F2, 
 GDK_o, GDK_a, 0x00E5, 
 GDK_o, GDK_c, 0x00A9, 
 GDK_o, GDK_e, 0x0153, 
@@ -1883,18 +2362,68 @@ GDK_o, GDK_u, 0x016F, 
 GDK_o, GDK_w, 0x1E98, 
 GDK_o, GDK_x, 0x00A4, 
 GDK_o, GDK_y, 0x1E99, 
+GDK_o, GDK_asciitilde, 0x00F5, 
+GDK_o, GDK_diaeresis, 0x00F6, 
+GDK_o, GDK_acute, 0x00F3, 
 GDK_p, GDK_exclam, 0x00B6, 
+GDK_p, GDK_period, 0x1E57, 
+GDK_r, GDK_apostrophe, 0x0155, 
+GDK_r, GDK_comma, 0x0157, 
+GDK_r, GDK_less, 0x0159, 
+GDK_s, GDK_exclam, 0x00A7, 
+GDK_s, GDK_apostrophe, 0x015B, 
+GDK_s, GDK_comma, 0x015F, 
+GDK_s, GDK_period, 0x1E61, 
+GDK_s, GDK_0, 0x00A7, 
+GDK_s, GDK_1, 0x00B9, 
+GDK_s, GDK_2, 0x00B2, 
+GDK_s, GDK_3, 0x00B3, 
+GDK_s, GDK_less, 0x0161, 
 GDK_s, GDK_M, 0x2120, 
 GDK_s, GDK_m, 0x2120, 
 GDK_s, GDK_o, 0x00A7, 
 GDK_s, GDK_s, 0x00DF, 
+GDK_s, GDK_cedilla, 0x015F, 
+GDK_t, GDK_minus, 0x0167, 
+GDK_t, GDK_period, 0x1E6B, 
+GDK_t, GDK_slash, 0x0167, 
+GDK_t, GDK_less, 0x0165, 
 GDK_t, GDK_M, 0x2122, 
 GDK_t, GDK_h, 0x00FE, 
 GDK_t, GDK_m, 0x2122, 
+GDK_u, GDK_quotedbl, 0x00FC, 
+GDK_u, GDK_apostrophe, 0x00FA, 
+GDK_u, GDK_asterisk, 0x016F, 
+GDK_u, GDK_comma, 0x0173, 
+GDK_u, GDK_minus, 0x016B, 
+GDK_u, GDK_slash, 0x00B5, 
+GDK_u, GDK_greater, 0x00FB, 
+GDK_u, GDK_asciicircum, 0x00FB, 
+GDK_u, GDK_underscore, 0x016B, 
+GDK_u, GDK_grave, 0x00F9, 
 GDK_u, GDK_u, 0x016D, 
+GDK_u, GDK_asciitilde, 0x0169, 
+GDK_u, GDK_diaeresis, 0x00FC, 
+GDK_u, GDK_acute, 0x00FA, 
+GDK_v, GDK_Z, 0x017D, 
 GDK_v, GDK_l, 0x007C, 
+GDK_v, GDK_z, 0x017E, 
+GDK_w, GDK_asciicircum, 0x0175, 
+GDK_x, GDK_0, 0x00A4, 
+GDK_x, GDK_O, 0x00A4, 
 GDK_x, GDK_o, 0x00A4, 
 GDK_x, GDK_x, 0x00D7, 
+GDK_y, GDK_quotedbl, 0x00FF, 
+GDK_y, GDK_apostrophe, 0x00FD, 
+GDK_y, GDK_minus, 0x00A5, 
+GDK_y, GDK_equal, 0x00A5, 
+GDK_y, GDK_asciicircum, 0x0177, 
+GDK_y, GDK_diaeresis, 0x00FF, 
+GDK_y, GDK_acute, 0x00FD, 
+GDK_z, GDK_apostrophe, 0x017A, 
+GDK_z, GDK_period, 0x017C, 
+GDK_z, GDK_less, 0x017E, 
+GDK_bar, GDK_C, 0x00A2, 
 GDK_bar, GDK_c, 0x00A2, 
 GDK_asciitilde, GDK_space, 0x007E, 
 GDK_asciitilde, GDK_A, 0x00C3, 
@@ -1952,7 +2481,19 @@ GDK_asciitilde, 0x1F61, 0x1F67, 
 GDK_asciitilde, 0x1F68, 0x1F6E, 
 GDK_asciitilde, 0x1F69, 0x1F6F, 
 GDK_diaeresis, GDK_apostrophe, 0x0385, 
+GDK_diaeresis, GDK_A, 0x00C4, 
+GDK_diaeresis, GDK_E, 0x00CB, 
+GDK_diaeresis, GDK_I, 0x00CF, 
+GDK_diaeresis, GDK_O, 0x00D6, 
+GDK_diaeresis, GDK_U, 0x00DC, 
+GDK_diaeresis, GDK_Y, 0x0178, 
 GDK_diaeresis, GDK_grave, 0x1FED, 
+GDK_diaeresis, GDK_a, 0x00E4, 
+GDK_diaeresis, GDK_e, 0x00EB, 
+GDK_diaeresis, GDK_i, 0x00EF, 
+GDK_diaeresis, GDK_o, 0x00F6, 
+GDK_diaeresis, GDK_u, 0x00FC, 
+GDK_diaeresis, GDK_y, 0x00FF, 
 GDK_diaeresis, GDK_asciitilde, 0x1FC1, 
 GDK_diaeresis, GDK_acute, 0x0385, 
 GDK_diaeresis, GDK_dead_grave, 0x1FED, 
@@ -2137,6 +2678,8 @@ GDK_cedilla, GDK_n, 0x0146, 
 GDK_cedilla, GDK_r, 0x0157, 
 GDK_cedilla, GDK_s, 0x015F, 
 GDK_cedilla, GDK_t, 0x0163, 
+GDK_breve, GDK_G, 0x011E, 
+GDK_breve, GDK_g, 0x011F, 
 0x05B4, GDK_hebrew_yod, 0xFB1D, 
 0x05B7, 0x05F2, 0xFB1F, 
 0x05B7, GDK_hebrew_aleph, 0xFB2E, 
@@ -2184,6 +2727,20 @@ GDK_Cyrillic_IE, GDK_equal, 0x20AC, 
 GDK_Cyrillic_EN, GDK_Cyrillic_o, 0x2116, 
 GDK_Cyrillic_EN, GDK_Cyrillic_O, 0x2116, 
 GDK_Cyrillic_ES, GDK_equal, 0x20AC, 
+GDK_Greek_ALPHA, GDK_apostrophe, 0x0386, 
+GDK_Greek_EPSILON, GDK_apostrophe, 0x0388, 
+GDK_Greek_ETA, GDK_apostrophe, 0x0389, 
+GDK_Greek_IOTA, GDK_quotedbl, 0x03AA, 
+GDK_Greek_IOTA, GDK_apostrophe, 0x038A, 
+GDK_Greek_OMICRON, GDK_apostrophe, 0x038C, 
+GDK_Greek_UPSILON, GDK_quotedbl, 0x03AB, 
+GDK_Greek_UPSILON, GDK_apostrophe, 0x038E, 
+GDK_Greek_OMEGA, GDK_apostrophe, 0x038F, 
+GDK_Greek_alpha, GDK_apostrophe, 0x03AC, 
+GDK_Greek_epsilon, GDK_apostrophe, 0x03AD, 
+GDK_Greek_eta, GDK_apostrophe, 0x03AE, 
+GDK_Greek_iota, GDK_quotedbl, 0x03CA, 
+GDK_Greek_iota, GDK_apostrophe, 0x03AF, 
 GDK_Greek_iota, GDK_Greek_alphaaccent, 0x1FB4, 
 GDK_Greek_iota, GDK_Greek_etaaccent, 0x1FC4, 
 GDK_Greek_iota, GDK_Greek_omegaaccent, 0x1FF4, 
@@ -2247,6 +2804,10 @@ GDK_Greek_iota, 0x1F7C, 0x1FF2, 
 GDK_Greek_iota, 0x1FB6, 0x1FB7, 
 GDK_Greek_iota, 0x1FC6, 0x1FC7, 
 GDK_Greek_iota, 0x1FF6, 0x1FF7, 
+GDK_Greek_omicron, GDK_apostrophe, 0x03CC, 
+GDK_Greek_upsilon, GDK_quotedbl, 0x03CB, 
+GDK_Greek_upsilon, GDK_apostrophe, 0x03CD, 
+GDK_Greek_omega, GDK_apostrophe, 0x03CE, 
 GDK_lessthanequal, 0x0338, 0x2270, 
 GDK_greaterthanequal, 0x0338, 0x2271, 
 GDK_approximate, 0x0338, 0x2247, 
@@ -2635,6 +3196,9 @@ GDK_exclam, GDK_dead_horn, GDK_O, 0x1EE2
 GDK_exclam, GDK_dead_horn, GDK_U, 0x1EF0, 
 GDK_exclam, GDK_dead_horn, GDK_o, 0x1EE3, 
 GDK_exclam, GDK_dead_horn, GDK_u, 0x1EF1, 
+GDK_quotedbl, GDK_apostrophe, GDK_space, 0x0385, 
+GDK_quotedbl, GDK_apostrophe, GDK_Greek_iota, 0x0390, 
+GDK_quotedbl, GDK_apostrophe, GDK_Greek_upsilon, 0x03B0, 
 GDK_quotedbl, GDK_underscore, GDK_U, 0x1E7A, 
 GDK_quotedbl, GDK_underscore, GDK_u, 0x1E7B, 
 GDK_quotedbl, GDK_asciitilde, GDK_O, 0x1E4E, 
@@ -2645,6 +3209,7 @@ GDK_quotedbl, GDK_dead_tilde, GDK_O, 0x1
 GDK_quotedbl, GDK_dead_tilde, GDK_o, 0x1E4F, 
 GDK_quotedbl, GDK_dead_macron, GDK_U, 0x1E7A, 
 GDK_quotedbl, GDK_dead_macron, GDK_u, 0x1E7B, 
+GDK_apostrophe, GDK_quotedbl, GDK_space, 0x0385, 
 GDK_apostrophe, GDK_quotedbl, GDK_I, 0x1E2E, 
 GDK_apostrophe, GDK_quotedbl, GDK_U, 0x01D7, 
 GDK_apostrophe, GDK_quotedbl, GDK_i, 0x1E2F, 
@@ -2948,6 +3513,7 @@ GDK_parenleft, GDK_KP_6, GDK_parenright,
 GDK_parenleft, GDK_KP_7, GDK_parenright, 0x2466, 
 GDK_parenleft, GDK_KP_8, GDK_parenright, 0x2467, 
 GDK_parenleft, GDK_KP_9, GDK_parenright, 0x2468, 
+GDK_minus, GDK_minus, GDK_space, 0x00AD, 
 GDK_minus, GDK_minus, GDK_minus, 0x2014, 
 GDK_minus, GDK_minus, GDK_period, 0x2013, 
 GDK_period, GDK_exclam, GDK_S, 0x1E68, 


Index: gtk2.spec
===================================================================
RCS file: /cvs/extras/rpms/gtk2/F-10/gtk2.spec,v
retrieving revision 1.336
retrieving revision 1.337
diff -u -r1.336 -r1.337
--- gtk2.spec	24 Nov 2008 18:55:04 -0000	1.336
+++ gtk2.spec	28 Nov 2008 00:10:45 -0000	1.337
@@ -16,7 +16,7 @@
 Summary: The GIMP ToolKit (GTK+), a library for creating GUIs for X
 Name: gtk2
 Version: %{base_version}
-Release: 1%{?dist}
+Release: 2%{?dist}
 License: LGPLv2+
 Group: System Environment/Libraries
 Source: http://download.gnome.org/sources/gtk+/2.14/gtk+-%{version}.tar.bz2
@@ -30,6 +30,8 @@
 # a workaround for some brokenness in the flash plugin
 # see http://bugzilla.gnome.org/show_bug.cgi?id=463773
 Patch2: workaround.patch
+# from upstream
+Patch3: missing-compose-seqs.patch
 
 BuildRequires: atk-devel >= %{atk_version}
 BuildRequires: pango-devel >= %{pango_version}
@@ -116,6 +118,7 @@
 %patch0 -p1 -b .lib64
 %patch1 -p1 -b .set-invisible-char-to-bullet
 %patch2 -p1 -b .workaround
+%patch3 -p1 -b .missing-compose-seqs
 
 for i in config.guess config.sub ; do
   test -f %{_datadir}/libtool/$i && cp %{_datadir}/libtool/$i .
@@ -297,6 +300,10 @@
 %{_datadir}/gtk-2.0
 
 %changelog
+* Thu Nov 27 2008 Matthias Clasen <mclasen at redhat.com> - 2.14.5-2
+- Re-add compose sequences that went missing due to the table
+  syncing with X.org
+
 * Mon Nov 24 2008 Matthias Clasen <mclasen at redhat.com> - 2.14.5-1
 - Update to 2.14.5
 




More information about the fedora-extras-commits mailing list
diff -up gtk+-2.14.5/gtk/gtkimcontextsimple.c.compose-seqs gtk+-2.14.5/gtk/gtkimcontextsimple.c
--- gtk+-2.14.5/gtk/gtkimcontextsimple.c.compose-seqs	2008-11-27 19:07:04.000000000 -0500
+++ gtk+-2.14.5/gtk/gtkimcontextsimple.c	2008-11-27 19:07:26.000000000 -0500
@@ -53,7 +53,7 @@ struct _GtkComposeTableCompact
  */
 #include "gtkimcontextsimpleseqs.h"
 
 /* From the values below, the value 22 means the number of different first keysyms 
  * that exist in the Compose file (from Xorg). When running compose-parse.py without 
  * parameters, you get the count that you can put here. Needed when updating the
  * gtkimcontextsimpleseqs.h header file (contains the compose sequences).
@@ -61,7 +61,7 @@ struct _GtkComposeTableCompact
 static const GtkComposeTableCompact gtk_compose_table_compact = {
   gtk_compose_seqs_compact,
   5,
-  22,
+  23,
   6
 };
 
@@ -415,7 +415,7 @@ check_normalize_nfc (gunichar* combinati
  * In future versions it will be just the keysym (no +1).
  */
 #define IS_DEAD_KEY(k) \
-    ((k) >= GDK_dead_grave && (k) <= (GDK_dead_dasia+1))
+    ((k) >= GDK_dead_stroke && (k) <= (GDK_dead_dasia+1))
 
 static gboolean
 check_algorithmically (GtkIMContextSimple    *context_simple,
@@ -53,7 +53,7 @@ struct _GtkComposeTableCompact
 #include "gtkimcontextsimpleseqs.h"
 
-/* From the values below, the value 22 means the number of different first keysyms 
+/* From the values below, the value 23 means the number of different first keysyms 
  * that exist in the Compose file (from Xorg). When running compose-parse.py without 
  * parameters, you get the count that you can put here. Needed when updating the